@@ -136,6 +136,7 @@ net_rules = _make_attr_filter('rules')
 net_physical_network = _make_attr_filter('physical_network')
 net_bootproto = _make_attr_filter('bootproto')
 net_defroute = _make_attr_filter('defroute')
+net_ethtool_opts = _make_attr_filter('ethtool_opts')
 
 
 @jinja2.contextfilter
@@ -178,6 +179,7 @@ def _route_obj(route):
     optional = {
         'gateway',
         'table',
+        'options',
     }
     for option in optional:
         if option in route:
@@ -213,6 +215,7 @@ def net_interface_obj(context, name, inventory_hostname=None):
     rules = net_rules(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
     defroute = net_defroute(context, name, inventory_hostname)
+    ethtool_opts = net_ethtool_opts(context, name, inventory_hostname)
     vip_address = net_vip_address(context, name, inventory_hostname)
     allowed_addresses = [vip_address] if vip_address else None
     interface = {
@@ -226,6 +229,7 @@ def net_interface_obj(context, name, inventory_hostname=None):
         'rules': rules,
         'bootproto': bootproto or 'static',
         'defroute': defroute,
+        'ethtool_opts': ethtool_opts,
         'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
     }
@@ -262,6 +266,7 @@ def net_bridge_obj(context, name, inventory_hostname=None):
     rules = net_rules(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
     defroute = net_defroute(context, name, inventory_hostname)
+    ethtool_opts = net_ethtool_opts(context, name, inventory_hostname)
     vip_address = net_vip_address(context, name, inventory_hostname)
     allowed_addresses = [vip_address] if vip_address else None
     interface = {
@@ -276,6 +281,7 @@ def net_bridge_obj(context, name, inventory_hostname=None):
         'rules': rules,
         'bootproto': bootproto or 'static',
         'defroute': defroute,
+        'ethtool_opts': ethtool_opts,
         'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
     }
@@ -318,6 +324,7 @@ def net_bond_obj(context, name, inventory_hostname=None):
     rules = net_rules(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
     defroute = net_defroute(context, name, inventory_hostname)
+    ethtool_opts = net_ethtool_opts(context, name, inventory_hostname)
     vip_address = net_vip_address(context, name, inventory_hostname)
     allowed_addresses = [vip_address] if vip_address else None
     interface = {
@@ -338,6 +345,7 @@ def net_bond_obj(context, name, inventory_hostname=None):
         'rules': rules,
         'bootproto': bootproto or 'static',
         'defroute': defroute,
+        'ethtool_opts': ethtool_opts,
         'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
     }
@@ -424,6 +432,11 @@ def net_configdrive_network_device(context, name, inventory_hostname=None):
     gateway = net_gateway(context, name, inventory_hostname)
     bootproto = net_bootproto(context, name, inventory_hostname)
     mtu = net_mtu(context, name, inventory_hostname)
+    vlan = net_vlan(context, name, inventory_hostname)
+    if vlan and '.' in device:
+        backend = [device.split('.')[0]]
+    else:
+        backend = None
     interface = {
         'device': device,
         'address': ip,
@@ -431,7 +444,10 @@ def net_configdrive_network_device(context, name, inventory_hostname=None):
         'gateway': gateway,
         'bootproto': bootproto or 'static',
         'mtu': mtu,
+        'backend': backend,
     }
+    if backend:
+        interface['type'] = 'vlan'
     interface = {k: v for k, v in interface.items() if v is not None}
     return interface
 
@@ -494,6 +510,7 @@ class FilterModule(object):
             'net_physical_network': net_physical_network,
             'net_bootproto': net_bootproto,
             'net_defroute': net_defroute,
+            'net_ethtool_opts': net_ethtool_opts,
             'net_interface_obj': net_interface_obj,
             'net_bridge_obj': net_bridge_obj,
             'net_bond_obj': net_bond_obj,
