@@ -27,7 +27,8 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
 
 @pytest.mark.parametrize(
     'path',
-    ['barbican',
+    ['aodh',
+     'barbican',
      'cinder',
      'cloudkitty',
      'designate',
@@ -44,6 +45,7 @@ testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
      'magnum',
      'manila',
      'mariadb',
+     'masakari',
      'monasca',
      'murano',
      'neutron',
@@ -61,7 +63,8 @@ def test_service_config_directory(host, path):
 
 @pytest.mark.parametrize(
     'path',
-    ['barbican.conf',
+    ['aodh.conf',
+     'barbican.conf',
      'cinder.conf',
      'cloudkitty.conf',
      'designate.conf',
@@ -75,8 +78,9 @@ def test_service_config_directory(host, path):
      'keystone.conf',
      'magnum.conf',
      'manila.conf',
-     'neutron/ml2_conf.ini',
+     'masakari.conf',
      'murano.conf',
+     'neutron/ml2_conf.ini',
      'neutron.conf',
      'nova.conf',
      'octavia.conf',
